==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangDoubleNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangDoubleNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 973a285307ea6804 soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method$v$3dd43d4f40cf1b96(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangDoubleNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangDoubleNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 973a285307ea6804 soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$method$v$3dd43d4f40cf1b96(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangDoubleNative_H_ */
